/**
 * Check whether the date is valid
 * @param date The date
 * @returns A boolean indicating whether the date is valid
 */
export declare function dateIsValid(date: Date): boolean;
/**
 * Check whether the date is the first day of the month
 * @param date The date
 * @returns A boolean indicating whether the date is the first day of the month
 */
export declare function dateIsFirstDayOfMonth(date: Date): boolean;
/**
 * Check whether the date is the last day of the month
 * @param date The date
 * @returns A boolean indicating whether the date is the last day of the month
 */
export declare function dateIsLastDayOfMonth(date: Date): boolean;
/**
 * Check whether the date is a leap year
 * @param date The date
 * @returns A boolean indicating whether the date is a leap year
 */
export declare function dateIsLeapYear(date: Date): boolean;
/**
 * Check whether the date is a weekend
 * @param date The date
 * @returns A boolean indicating whether the date is a weekend
 */
export declare function dateIsWeekend(date: Date): boolean;
/**
 * Calculate the difference in days between two dates
 * The order is not relevant hence the result is always positive
 * @param from The start date
 * @param to The end date
 * @returns The difference in days between two dates
 */
export declare function dateDifferenceInDays(from: Date, to: Date): number;
/**
 * Get the next business date
 * @param date The date
 * @returns The next business date
 */
export declare function getNextBusinessDate(date: Date): Date;
/**
 * Get the start of a day for the given date
 * @param date The date
 * @returns The start of a day date
 */
export declare function getStartOfDay(date: Date): Date;
/**
 * Get the end of a day for the given date
 * @param date The date
 * @returns The end of a day date
 */
export declare function getEndOfDay(date: Date): Date;
/**
 * Get the last day of a year for the given date
 * @param date The date
 * @returns The last day of the date year
 */
export declare function getLastDayOfYear(date: Date): Date;
